is_loguru_mode = False

try:
    from group_center.utils.log.backend_loguru import get_loguru_backend

    is_loguru_mode = True
except ImportError:
    is_loguru_mode = False

from group_center.utils.log.backend_logging import get_logging_backend
from group_center.utils.log.backend_print import get_print_backend

__is_print_mode = True


def set_is_print_mode(is_print: bool):
    global __is_print_mode
    __is_print_mode = is_print


logger = None


def __init_logger():
    global logger
    if logger is not None:
        return

    if __is_print_mode:
        logger = get_print_backend()
    else:
        if is_loguru_mode:
            logger = get_loguru_backend()
        else:
            logger = get_logging_backend()


def set_logger(exist_logger):
    global logger
    logger = exist_logger


def get_logger():
    __init_logger()

    global logger
    return logger



import json
import queue
import threading
import time
from queue import Queue
from typing import Tuple

import requests

from group_center.core import group_center_machine
from group_center.core.group_center_machine import logger


def send_dict_to_center(data: dict, target: str) -> bool:
    url = group_center_machine.group_center_get_url(target_api=target)
    try:
        response = requests.post(url, json=data, timeout=10)

        response_dict: dict = json.loads(response.text)

        if not (
                "isAuthenticated" in response_dict.keys()
                and response_dict["isAuthenticated"]
        ):
            logger.error("[Group Center] Not authorized")
            group_center_machine.group_center_login()
            return False

        if not ("isSucceed" in response_dict.keys() and response_dict["isSucceed"]):
            logger.error(f"[Group Center] Send {target} Failed: {response.text}")
            return False

        logger.info(f"[Group Center] Send {target} Success")
        return True
    except Exception as e:
        logger.error(f"[Group Center] Send {target} Failed: {e}")
        return False


task_queue: Queue[Tuple[dict, str]] = Queue()


class GroupCenterWorkThread(threading.Thread):
    def __init__(self):
        super(GroupCenterWorkThread, self).__init__()
        self._stop_event = threading.Event()

    def stop(self):
        self._stop_event.set()

    def run(self):
        while not self._stop_event.is_set():
            group_center_machine.get_access_key()

            try:
                data, target = task_queue.get(timeout=10)
                final_data = {
                    **group_center_machine.get_public_part(),
                    **data,
                }
                if send_dict_to_center(data=final_data, target=target):
                    task_queue.task_done()
                else:
                    # 发送失败，将任务放回队列，以便重试
                    task_queue.put((data, target))
                    # 多休息一会儿再重试
                    time.sleep(20)
            except queue.Empty:
                pass
            except Exception as e:
                logger.error(f"[GroupCenter] Thread exception: {e}")


work_thread = None


def new_message_enqueue(data: dict, target: str):
    global task_queue, work_thread

    task_queue.put((data, target))

    if work_thread is not None and not work_thread.is_alive():
        work_thread = None

    if work_thread is None:
        work_thread = GroupCenterWorkThread()
        work_thread.start()



from group_center.user.system_user import SystemUser
from group_center.utils.linux.linux_system import *
from group_center.utils.linux.linux_user import *


class LinuxUser(SystemUser):

    def __init__(self, user_name: str):
        if not is_run_on_linux():
            raise Exception("Current system is not linux")
        super().__init__(user_name=user_name)

    def is_exist(self) -> bool:
        return check_linux_user_is_exist(self.user_name)

    def get_home_directory(self) -> str:
        return get_user_home_directory(self.user_name)

    def create(self, password: str = "") -> bool:
        return create_linux_user(self.user_name, password)

    def reset_password(self, password: str = "") -> bool:
        return reset_password(self.user_name, password)

    def delete(self, delete_home: bool = True) -> bool:
        return delete_linux_user(self.user_name, delete_home)

    def add_to_group(self, group_name: str) -> bool:
        return add_user_to_group(self.user_name, group_name)

    def get_groups(self) -> str:
        return get_user_groups(self.user_name)

    def get_groups_list(self) -> List[str]:
        return get_user_groups_list(self.user_name)

    @property
    def uid(self):
        return get_uid(self.user_name)

    @uid.setter
    def uid(self, value):
        if not isinstance(value, int):
            raise ValueError("uid must be int")
        if value == get_uid(self.user_name):
            return
        set_uid(self.user_name, value)

    @property
    def gid(self):
        return get_gid(self.user_name)

    @gid.setter
    def gid(self, value):
        if not isinstance(value, int):
            raise ValueError("gid must be int")
        if value == get_gid(self.user_name):
            return
        set_gid(self.user_name, value)


if __name__ == "__main__":
    print()



import json
from typing import Tuple

import requests

from group_center.core import group_center_encrypt
from group_center.core.config_core import get_env_machine_config
from group_center.utils.log.logger import get_logger

GROUP_CENTER_URL = ""
MACHINE_NAME_FULL = ""
MACHINE_NAME_SHORT = ""
MACHINE_PASSWORD = ""

access_key = ""

group_center_public_part: dict = {
    "serverName": MACHINE_NAME_FULL,
    "serverNameEng": MACHINE_NAME_SHORT,
}

logger = None


def init_logger():
    global logger
    if logger is None:
        logger = get_logger()


def set_logger(exist_logger):
    global logger
    logger = exist_logger


def set_group_center_host_url(host_url: str):
    global GROUP_CENTER_URL
    GROUP_CENTER_URL = host_url


def set_machine_name_full(server_name: str):
    global MACHINE_NAME_FULL
    MACHINE_NAME_FULL = server_name


def set_machine_name_short(server_name_short: str):
    global MACHINE_NAME_SHORT
    MACHINE_NAME_SHORT = server_name_short


def set_machine_password(password: str):
    global MACHINE_PASSWORD
    MACHINE_PASSWORD = password


def __init_from_env(skip_if_exist: bool = True):
    if skip_if_exist and GROUP_CENTER_URL != "":
        return

    env_machine_config: Tuple[str, str, str, str] = get_env_machine_config()

    set_group_center_host_url(env_machine_config[0])
    set_machine_name_full(env_machine_config[1])
    set_machine_name_short(env_machine_config[2])
    set_machine_password(env_machine_config[3])


def group_center_get_url(target_api: str):
    __init_from_env()

    global GROUP_CENTER_URL

    if GROUP_CENTER_URL.endswith("/"):
        if target_api.startswith("/"):
            target_api = target_api[1:]
    else:
        if not target_api.startswith("/"):
            target_api = "/" + target_api

    return GROUP_CENTER_URL + target_api


def get_public_part() -> dict:
    global group_center_public_part

    group_center_public_part.update({
        "serverName": MACHINE_NAME_FULL,
        "serverNameEng": MACHINE_NAME_SHORT,
        "accessKey": get_access_key(),
    })

    return group_center_public_part


def __group_center_login(username: str, password: str) -> bool:
    # Init logger if not set
    init_logger()

    logger.info("[Group Center] Login Start")
    url = group_center_get_url(target_api="/auth/client/auth")
    try:
        logger.info(f"[Group Center] Auth To: {url}")
        password_display = \
            group_center_encrypt.encrypt_password_to_display(password)
        password_encoded = \
            group_center_encrypt.get_password_hash(password)
        logger.info(
            f"[Group Center] Auth userName:{username} password:{password_display}"
        )

        response = requests.get(
            url=url,
            params={"userName": username, "password": password_encoded},
            timeout=10,
        )

        if response.status_code != 200:
            logger.error(f"[Group Center] Auth Failed: {response.text}")
            return False

        response_dict: dict = json.loads(response.text)
        if not (
                "isAuthenticated" in response_dict.keys()
                and response_dict["isAuthenticated"]
        ):
            logger.error("[Group Center] Not authorized")
            return False
        global access_key
        access_key = response_dict["accessKey"]
        logger.info(f"[Group Center] Auth Handshake Success: {access_key}")

    except Exception as e:
        logger.error(f"[Group Center] Auth Handshake Failed: {e}")
        return False

    logger.info("[Group Center] Login Finished.")


def group_center_login() -> bool:
    __init_from_env()

    return __group_center_login(
        username=MACHINE_NAME_SHORT, password=MACHINE_PASSWORD
    )


def get_access_key() -> str:
    global access_key

    if access_key == "":
        group_center_login()

    return access_key



from typing import List

from group_center.client.user.datatype.user_info import UserInfo
from group_center.user.linux.linux_user import LinuxUser


def get_linux_user_add_text(
        user_name: str,
        password: str,
        uid: int,
        gid: int,
        group_name: str,
        home_dir: str,
        shell: str,
):
    # user001::600:100:user:/home/user001:/bin/bash
    return f"{user_name}:{password}:{uid}:{gid}:{group_name}:{home_dir}:{shell}"


def linux_add_user_txt(user_info_list: List[UserInfo], password: str = ""):
    final_text = ""

    for user_info in user_info_list:
        user_name: str = user_info.name_eng

        uid: int = user_info.linux_user.uid
        gid: int = user_info.linux_user.gid

        group_name: str = user_name
        home_dir: str = user_info.home_dir
        shell: str = "/bin/bash"

        final_text += get_linux_user_add_text(
            user_name=user_name,
            password=password,
            uid=uid,
            gid=gid,
            group_name=group_name,
            home_dir=home_dir,
            shell=shell,
        ) + "\n"

    return final_text.strip()


def create_user(user_info: UserInfo, password: str = ""):
    linux_user_obj = LinuxUser(user_info.name_eng)

    if not linux_user_obj.is_exist():
        print(f"User {user_info.name_eng} already exist")

        if not linux_user_obj.create(password=password):
            print(f"Create user {user_info.name_eng} failed")
            return

    linux_user_obj.uid = user_info.linux_user.uid
    linux_user_obj.gid = user_info.linux_user.gid


def create_linux_users(user_info_list: List[UserInfo], password: str = ""):
    for user_info in user_info_list:
        create_user(user_info=user_info, password=password)



import os


def get_env_string(key: str, default_value: str = ""):
    return str(os.environ.get(key, default_value)).strip()


def get_env_int(key: str, default_value: int) -> int:
    try:
        return int(os.environ.get(key, default_value))
    except ValueError:
        return default_value



from group_center.utils.log.log_level import get_log_level


class BackendPrint:
    class Level:
        INFO = 0
        ERROR = 1
        WARNING = 2
        DEBUG = 3

    level: Level = 0

    def __init__(self):
        self.level = self.Level.INFO

    def set_level(self, level: Level):
        self.level = level

    def debug(self, message):
        get_log_level().DEBUG.is_valid()
        print(message)

    def info(self, message):
        get_log_level().INFO.is_valid()
        print(message)

    def success(self, message):
        get_log_level().INFO.is_valid()
        print(message)

    def error(self, message):
        get_log_level().ERROR.is_valid()
        print(message)

    def warning(self, message):
        get_log_level().WARNING.is_valid()
        print(message)

    def critical(self, message):
        get_log_level().CRITICAL.is_valid()
        print(message)


print_backend = None


def get_print_backend():
    global print_backend

    if print_backend is None:
        print_backend = BackendPrint()

    return print_backend



from group_center.feature.nvi_notify.machine_user_message import *
from group_center.user_env import *

global_user_name: str = ""
global_enable: bool = False


def group_center_set_is_valid(enable: bool = True):
    global global_enable
    global_enable = enable


def group_center_set_user_name(new_user_name: str):
    global global_user_name
    global_user_name = new_user_name.strip()


def push_message(
        content: str,
        user_name: str = "",
        only_first_card_process: bool = True,
) -> bool:
    if only_first_card_process and not is_first_card_process():
        return False

    global global_enable, global_user_name

    if not global_enable:
        return False

    if user_name == "":
        user_name = global_user_name.strip()
    return machine_user_message_via_local_nvi_notify(
        content=content,
        user_name=user_name,
    )



import requests

url: str = "http://localhost:8080"


def get_nvi_notify_api_url(target: str):
    return url.strip() + target.strip()


def send_to_nvi_notify(dict_data: dict, target: str) -> bool:
    response = requests.post(get_nvi_notify_api_url(target), data=dict_data)

    return response.status_code == 200



from typing import List


class LogLevelObject:
    level: int
    level_name: str
    level_threshold: int

    def __init__(self):
        self.level = 0
        self.level_name = ""
        self.level_threshold = 0

    def is_valid(self) -> bool:
        return (
                self.level > 0 and
                0 < self.level_threshold <= self.level
        )

    def __int__(self):
        return self.level


class LogLevel:
    __level_list: List[LogLevelObject]

    __current_level: LogLevelObject

    DEBUG: LogLevelObject
    INFO: LogLevelObject
    SUCCESS: LogLevelObject
    WARNING: LogLevelObject
    ERROR: LogLevelObject
    CRITICAL: LogLevelObject

    def __init__(self):
        self.__level_list = []

        self.DEBUG = LogLevelObject()
        self.INFO = LogLevelObject()
        self.SUCCESS = LogLevelObject()
        self.WARNING = LogLevelObject()
        self.ERROR = LogLevelObject()
        self.CRITICAL = LogLevelObject()

        self.__level_list.append(self.DEBUG)
        self.__level_list.append(self.INFO)
        self.__level_list.append(self.SUCCESS)
        self.__level_list.append(self.WARNING)
        self.__level_list.append(self.ERROR)
        self.__level_list.append(self.CRITICAL)

        self.DEBUG.level_name = "DEBUG"
        self.INFO.level_name = "INFO"
        self.SUCCESS.level_name = "SUCCESS"
        self.WARNING.level_name = "WARNING"
        self.ERROR.level_name = "ERROR"
        self.CRITICAL.level_name = "CRITICAL"

        for index, level in enumerate(self.__level_list):
            level.level = index + 1

        self.current_level = self.INFO

    @property
    def current_level(self) -> LogLevelObject:
        return self.__current_level

    @current_level.setter
    def current_level(self, value: int):
        if isinstance(value, LogLevelObject):
            self.__current_level = value
            self.update_level_threshold()
            return

        if not isinstance(value, int):
            value = int(value)

        for level in self.__level_list:
            if level.level == value:
                self.__current_level = level
                self.update_level_threshold()
                return

        raise ValueError("Invalid log level")

    def update_level_threshold(self):
        for level in self.__level_list:
            level.level_threshold = self.current_level.level

    def get_loguru_level(self):
        return self.__current_level.level_name

    def get_logging_level(self):
        import logging

        level_name = self.__current_level.level_name

        # Replace SUCCESS with INFO
        if level_name == "SUCCESS":
            level_name = "INFO"

        return getattr(logging, level_name)


__log_level = LogLevel()


def get_log_level() -> LogLevel:
    return __log_level



import os

from config import global_config

__version__ = "1.5.0"


def get_version_path() -> str:
    return os.path.join(global_config.path_dir_config, "version.txt")


def get_version(version_path) -> str:
    if not os.path.exists(version_path):
        return ""

    with open(version_path, "r", encoding="utf-8") as f:
        content = f.read().strip()

    version_list = content.split(".")

    if len(version_list) != 3:
        return ""

    for i in version_list:
        if not i.isdigit():
            return ""

    return content


if __name__ == "__main__":
    print(__version__)



import os

current_py_path = os.path.abspath(__file__)
path_dir_config = os.path.dirname(current_py_path)
path_dir_base = os.path.dirname(path_dir_config)

if __name__ == "__main__":
    print(path_dir_base)



from typing import List

from group_center.client.user. \
    datatype.linux_user import LinuxUserJava
from group_center.client.user. \
    datatype.webhook import AllWebHookUser


class UserInfo:
    name: str = ""
    name_eng: str = ""
    keywords: List[str]
    year: int = 0

    linux_user: LinuxUserJava
    webhook: AllWebHookUser

    def __init__(self):
        self.keywords = []
        self.linux_user = LinuxUserJava()
        self.webhook = AllWebHookUser()

    def from_dict(self, dict_data: dict):
        self.name = dict_data["name"]
        self.name_eng = dict_data["nameEng"]
        self.keywords = dict_data["keywords"]
        self.year = dict_data["year"]

        self.linux_user.from_dict(dict_data["linuxUser"])

    @property
    def home_dir(self):
        return f"/home/{self.name_eng}"


def get_user_info_list(user_list: List[dict]) -> List[UserInfo]:
    final_list = []

    for user_dict in user_list:
        user_info = UserInfo()
        user_info.from_dict(user_dict)

        final_list.append(user_info)

    return final_list



from group_center.feature.nvi_notify import notify_api
from group_center.utils.linux.linux_user import get_current_user_name

__all__ = ["machine_user_message_via_local_nvi_notify"]


def machine_user_message_via_local_nvi_notify(
        content: str,
        user_name: str = "",
) -> bool:
    user_name = user_name.strip()

    if user_name == "":
        user_name = get_current_user_name()

    if user_name == "":
        return False

    data_dict: dict = {
        "userName": user_name,
        "content": content,
    }

    try:
        notify_api.send_to_nvi_notify(
            dict_data=data_dict,
            target="/machine_user_message"
        )

        return True
    except Exception:
        # Ignore all errors to avoid program crash.
        return False



import os
import subprocess
from typing import Optional, List

user_name_black_list = ["ubuntu", "root", "public"]


def create_linux_user(username: str, password: str) -> bool:
    if check_linux_user_is_exist(username):
        return True

    # Create User
    # -m: create home directory
    create_user_cmd = f'useradd -m "{username}" -s /bin/bash'
    create_user_process = (
        subprocess.run(create_user_cmd, shell=True, check=False))

    # Set Password
    set_password_cmd = f'echo {username}:{password} | chpasswd'
    set_password_process = \
        subprocess.run(set_password_cmd, shell=True, check=False)

    return (
            create_user_process.returncode == 0 and
            set_password_process.returncode == 0
    )


def check_linux_user_is_exist(username: str):
    check_user_cmd = f'id -u {username}'
    check_user_process = subprocess.run(
        check_user_cmd,
        shell=True,
        capture_output=True,
        text=True
    )

    return check_user_process.returncode == 0


def reset_password(username: str, password: Optional[str] = None) -> bool:
    if password is None:
        password = username
    reset_password_cmd = f'echo {username}:{password} | chpasswd'
    reset_password_process = \
        subprocess.run(reset_password_cmd, shell=True, check=False)
    return reset_password_process.returncode == 0


def delete_linux_user(username: str, delete_home: bool = True):
    if delete_home:
        subprocess.run(f'userdel -r {username}', shell=True, check=True)
        # subprocess.run(f'rm -rf /home/{username}', shell=True, check=True)
    else:
        subprocess.run(f'userdel {username}', shell=True, check=True)


def get_user_home_directory(username: str):
    get_home_cmd = f'getent passwd {username} | cut -d: -f6'
    get_home_process = subprocess.run(get_home_cmd, shell=True, capture_output=True, text=True)

    return get_home_process.stdout.strip()


def check_group_is_exist(group_name: str):
    check_group_cmd = f'getent group {group_name}'
    check_group_process = subprocess.run(check_group_cmd, shell=True, capture_output=True, text=True)

    return check_group_process.returncode == 0


def add_user_to_group(username: str, group_name: str) -> bool:
    if not check_group_is_exist(group_name):
        return False

    add_user_to_group_cmd = f'usermod -a -G {group_name} {username}'
    add_user_to_group_process = subprocess.run(add_user_to_group_cmd, shell=True, check=True)

    return add_user_to_group_process.returncode == 0


def get_user_groups(username: str) -> str:
    get_user_groups_cmd = f'id -Gn {username}'
    get_user_groups_process = \
        subprocess.run(
            get_user_groups_cmd,
            shell=True, capture_output=True, text=True
        )

    return get_user_groups_process.stdout.strip()


def get_user_groups_list(username: str) -> List[str]:
    result_list: List[str] = get_user_groups(username).split(" ")

    result_list = [
        item.strip()
        for item in result_list
        if len(item.strip()) > 0
    ]

    return result_list


def get_uid(username):
    try:
        result = subprocess.run(
            ['id', '-u', username],
            stdout=subprocess.PIPE,
            stderr=subprocess.PIPE,
            text=True
        )
        if result.returncode == 0:
            return int(result.stdout.strip())
        else:
            return 0
    except Exception as e:
        return 0


def get_gid(username):
    try:
        result = subprocess.run(
            ['id', '-g', username],
            stdout=subprocess.PIPE,
            stderr=subprocess.PIPE,
            text=True
        )
        if result.returncode == 0:
            return int(result.stdout.strip())
        else:
            return 0
    except Exception as e:
        return 0


def set_uid(username, uid):
    try:
        result = subprocess.run(
            ['usermod', '-u', str(uid), username],
            stdout=subprocess.PIPE,
            stderr=subprocess.PIPE,
            text=True
        )
        if result.returncode == 0:
            return True
        else:
            return False
    except Exception as e:
        return False


def set_gid(username, gid):
    try:
        result = subprocess.run(
            ['usermod', '-g', str(gid), username],
            stdout=subprocess.PIPE,
            stderr=subprocess.PIPE,
            text=True
        )
        if result.returncode == 0:
            return True
        else:
            return False
    except Exception as e:
        return False


def get_current_user_name() -> str:
    try:
        # 获取当前用户的用户名
        current_user = os.getlogin()

        # 检查用户名是否在黑名单中
        if current_user in user_name_black_list:
            return ""

        # 如果不在黑名单中，返回用户名
        return current_user.strip()
    except Exception:
        return ""


if __name__ == '__main__':
    # print("Is Exist:", check_linux_user_is_exist("userpy"))
    # print("Is Exist:", check_linux_user_is_exist("userpy0"))

    # create_linux_user("userpy", "password")

    print(get_user_home_directory("root"))



class SilentModeConfig:
    start_time: str = ""
    end_time: str = ""

    def from_dict(self, dict_data: dict):
        self.start_time = dict_data["startTime"]
        self.end_time = dict_data["endTime"]


class BaseWebHookUser:
    enable: bool = True

    def from_dict(self, dict_data: dict):
        self.enable = dict_data["enable"]


class WeComUser(BaseWebHookUser):
    user_id: str = ""
    user_mobile_phone: str = ""

    def from_dict(self, dict_data: dict):
        super().from_dict(dict_data=dict_data)
        self.user_id = dict_data["userId"]
        self.user_mobile_phone = dict_data["userMobilePhone"]


class LarkUser(BaseWebHookUser):
    user_id: str = ""
    user_mobile_phone: str = ""

    def from_dict(self, dict_data: dict):
        super().from_dict(dict_data=dict_data)
        self.user_id = dict_data["userId"]
        self.user_mobile_phone = dict_data["userMobilePhone"]


class AllWebHookUser:
    silent_mode: SilentModeConfig

    we_com: WeComUser
    lark: LarkUser

    def __init__(self):
        self.silent_mode = SilentModeConfig()

        self.we_com = WeComUser()
        self.lark = LarkUser()

    def from_dict(self, dict_data: dict):
        self.silent_mode.from_dict(dict_data=dict_data["silentMode"])

        self.we_com.from_dict(dict_data=dict_data["weCom"])
        self.lark.from_dict(dict_data=dict_data["lark"])



import argparse
from typing import List

from group_center.client.machine.feature.add_user import (
    linux_add_user_txt,
    create_linux_users,
)
from group_center.client.user.datatype.user_info import get_user_info_list, UserInfo
from group_center.core.feature.remote_config import (
    get_user_config_json_str,
)
from group_center.core.group_center_machine import *


def get_options():
    parser = argparse.ArgumentParser()

    parser.add_argument("--host", type=str, default="")
    parser.add_argument("--center-name", type=str, default="")
    parser.add_argument("--center-password", type=str, default="")

    parser.add_argument("--add-user-txt", type=str, default="")
    parser.add_argument("--user-password", type=str, default="")

    parser.add_argument("--year", type=int, default=0)

    parser.add_argument(
        "-c",
        "--create-user",
        help="Create Users",
        action="store_true",
    )

    opt = parser.parse_args()

    return opt


def connect_to_group_center(opt):
    set_group_center_host_url(opt.host)
    set_machine_name_short(opt.center_name)
    set_machine_password(opt.center_password)

    group_center_login()


def create_user(opt, user_info_list: List[UserInfo]):
    password: str = opt.user_password

    linux_add_user_text = create_linux_users(user_info_list, password)

    print(linux_add_user_text)


def save_add_user_text(opt, user_info_list: List[UserInfo]):
    save_path: str = opt.add_user_txt
    password: str = opt.user_password

    if not save_path:
        save_path = "add_user.txt"

    linux_add_user_text = linux_add_user_txt(
        user_info_list=user_info_list,
        password=password
    )

    with open(save_path, "w") as f:
        f.write(linux_add_user_text)


def main():
    opt = get_options()

    connect_to_group_center(opt)

    # Get User List
    user_config_json = get_user_config_json_str()
    user_dict_list = json.loads(user_config_json)
    user_info_list: List[UserInfo] = get_user_info_list(user_dict_list)

    if opt.year > 0:
        user_info_list = [
            user_info
            for user_info in user_info_list
            if user_info.year == opt.year
        ]

    if opt.create_user:
        create_user(opt, user_info_list)

    if opt.add_user_txt:
        save_add_user_text(opt, user_info_list)


if __name__ == "__main__":
    main()



import time

import requests

from group_center.core import group_center_machine
from group_center.utils.log.logger import get_logger

logger = get_logger()

max_retry_times = 5


def get_json_str(target_api: str) -> str:
    url = group_center_machine.group_center_get_url(target_api=target_api)

    for _ in range(max_retry_times):
        try:
            access_key = group_center_machine.get_access_key()

            params = {"accessKey": access_key}
            response = requests.get(url=url, params=params, timeout=10)

            text = response.text.strip()

            if response.status_code == 200:
                return text

            logger.error("[Group Center]" + text)
        except Exception as e:
            logger.error("get user config json error" + str(e))

        time.sleep(10)

    return ""


def get_user_config_json_str() -> str:
    return get_json_str(target_api="/api/client/config/user_list")


def get_env_json_str() -> str:
    return get_json_str(target_api="/api/client/config/env_list")


if __name__ == "__main__":
    json_text = get_user_config_json_str()
    print(json_text)

    print()



# -*- coding: utf-8 -*-

from pathlib import Path

from setuptools import setup, find_packages

from config.version import __version__

this_directory = Path(__file__).parent
with open(this_directory / "README.md", encoding="utf-8") as f:
    long_description = f.read()

setup(
    name="li_group_center",
    version=__version__,
    description="Group Center Tools",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/a645162/group-center-client",
    author="Haomin Kong",
    author_email="a645162@gmail.com",
    license="GPLv3",
    packages=find_packages(
        exclude=[
            "test",
        ]
    ),
    python_requires=">=3.6",
    install_requires=[
        "urllib3<2", "requests",
        "loguru"
    ],
    entry_points={
        "console_scripts": [
            "group_center_machine_user = group_center.client.machine.user_manager:main",
        ],
    },
)



import os
import re
import sys
from typing import List


def PythonVersion() -> str:
    version_str: str = str(sys.version)

    spilt_list: List[str] = version_str.split("|")

    version_str = spilt_list[0].strip()

    return version_str


def ENV_SCREEN_NAME_FULL() -> str:
    return os.getenv("STY", "").strip()


def ENV_SCREEN_SESSION_ID() -> str:
    spilt_list: List[str] = ENV_SCREEN_NAME_FULL().split(".")

    if len(spilt_list) < 2:
        return ""

    return spilt_list[0].strip()


def ENV_SCREEN_SESSION_NAME() -> str:
    spilt_list: List[str] = ENV_SCREEN_NAME_FULL().split(".")

    if len(spilt_list) < 2:
        return ""

    spilt_list = spilt_list[1:]

    return ".".join(spilt_list).strip()


def is_in_screen_session() -> bool:
    return ENV_SCREEN_SESSION_NAME() != ""


def ENV_CUDA_ROOT():
    cuda_home: str = os.getenv("CUDA_HOME", "").strip()
    nvcc_path: str = os.path.join(cuda_home, "bin", "nvcc")

    cuda_nvcc_bin: str = ""

    if os.path.exists(nvcc_path):
        cuda_nvcc_bin = nvcc_path
    else:
        cuda_toolkit_root = os.getenv("CUDAToolkit_ROOT", "").strip()
        nvcc_path = os.path.join(cuda_toolkit_root, "bin", "nvcc")
        if os.path.exists(nvcc_path):
            cuda_nvcc_bin = nvcc_path

    return cuda_nvcc_bin


def CUDA_VERSION(nvcc_path: str = "") -> str:
    nvcc_path = nvcc_path.strip()
    if nvcc_path == "" or (not os.path.exists(nvcc_path)):
        nvcc_path = ENV_CUDA_ROOT()
    if nvcc_path == "":
        return ""

    cuda_version: str = ""

    try:
        result = os.popen(f"{nvcc_path} --version").read()
        if "release" not in result:
            return ""
        result_list = result.split("\n")
        version: str = ""
        for line in result_list:
            if "release" in line:
                version = line.split(",")[-1].strip()
                break

        cuda_version = str(version).strip().lower().replace("v", "")
    except Exception:
        return ""

    return cuda_version


def ENV_CUDA_LOCAL_RANK() -> str:
    return os.getenv("LOCAL_RANK", "").strip()


def ENV_CUDA_WORLD_SIZE() -> str:
    return os.getenv("LOCAL_WORLD_SIZE", "").strip()


def cuda_local_rank() -> int:
    local_rank = ENV_CUDA_LOCAL_RANK()
    if local_rank == "":
        return -1
    try:
        return int(local_rank)
    except Exception:
        return -1


def cuda_world_size() -> int:
    world_size = ENV_CUDA_WORLD_SIZE()
    if world_size == "":
        return -1
    try:
        return int(world_size)
    except Exception:
        return -1


def is_first_card_process() -> bool:
    if cuda_world_size() < 2:
        return True

    return cuda_local_rank() == 0


def RUN_COMMAND() -> str:
    return " ".join(sys.argv).strip()


def CONDA_ENV_NAME() -> str:
    run_command = RUN_COMMAND()

    pattern = r"envs/(.*?)/bin/python "
    match = re.search(pattern, run_command)
    if match:
        conda_env_name = match.group(1)
        env_str = conda_env_name
    else:
        env_str = os.getenv("CONDA_DEFAULT_ENV", "")

    env_str = env_str.strip()

    if env_str == "":
        env_str = "base"

    return env_str


if __name__ == "__main__":
    print(PythonVersion())

    print(ENV_SCREEN_NAME_FULL())
    print(ENV_SCREEN_SESSION_ID())
    print(ENV_SCREEN_SESSION_NAME())

    print(ENV_CUDA_ROOT())
    print(CUDA_VERSION())

    print(ENV_CUDA_LOCAL_RANK())
    print(ENV_CUDA_WORLD_SIZE())

    print(RUN_COMMAND())
    print(CONDA_ENV_NAME())



import logging

from group_center.utils.log.log_level import get_log_level


def get_logging():
    log_level = get_log_level()

    logging.basicConfig(
        level=log_level.get_logging_level(),
        format="%(asctime)s - %(name)s - %(levelname)s - %(message)s"
    )
    return logging.getLogger(__name__)


def get_logging_backend():
    return get_logging()
